2. Some examples to illustrate py-altimetry functionalities — altimetry tools 0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- altimetry tools 0 documentation »

# 2. Some examples to illustrate py-altimetry functionalities

Handle data Others

## 2.1. Handle data

altimetry tools have a number of classes and function to handle data, mainly based on :mod:NetCDF4 package.

You can find examples of :

> - Loading NetCDF files
> - Handle altimetry data using altimetry.data.alti_data object

Note

Handling data may require knowlegde about how the NetCDF data is structured. You should therefore have a look at:

- informations about data structures

## 2.2. Others

> - Spectral analysis tools for altimetry data

### Navigation

- index
- modules |
- next |
- previous |
- altimetry tools 0 documentation »